@@ -1,6 +1,6 @@
 package Test::Magpie::ArgumentMatcher;
 {
-  $Test::Magpie::ArgumentMatcher::VERSION = '0.06';
+  $Test::Magpie::ArgumentMatcher::VERSION = '0.07';
 }
 # ABSTRACT: Various templates to catch arguments
 
@@ -21,6 +21,14 @@ sub anything {
     bless sub { return () }, __PACKAGE__;
 }
 
+sub custom_matcher (&;) {
+    my $test = shift;
+    bless sub {
+        local $_ = $_[0];
+        $test->(@_) ? () : undef
+    }, __PACKAGE__;
+}
+
 sub hash {
     my (%template) = @_;
     bless sub {
@@ -49,14 +57,6 @@ sub match {
     return $self->(@input);
 }
 
-sub custom_matcher (&;) {
-    my $test = shift;
-    bless sub {
-        local $_ = $_[0];
-        $test->(@_) ? () : undef
-    }, __PACKAGE__;
-}
-
 sub type {
     my $type = shift;
     bless sub {
@@ -157,13 +157,23 @@ duplicate arguments B<are ignored>. For example C<1, 1, 2> will match C<1, 2>,
 C<1, 2, 2>. This is probably a bug and I will fix it, but for now I'm mostly
 waiting for a bug report - sorry!
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Oliver Charles
+=over 4
+
+=item *
+
+Oliver Charles <oliver.g.charles@googlemail.com>
+
+=item *
+
+Steven Lee <stevenwh.lee@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Oliver Charles <oliver.g.charles@googlemail.com>.
+This software is copyright (c) 2013 by Oliver Charles.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
