@@ -1,6 +1,6 @@
 package Test::Magpie::Meta::Class;
 {
-  $Test::Magpie::Meta::Class::VERSION = '0.06';
+  $Test::Magpie::Meta::Class::VERSION = '0.07';
 }
 # ABSTRACT: Metaclass for mocks
 use Moose;
@@ -10,6 +10,7 @@ extends 'Moose::Meta::Class';
 
 override 'does_role' => sub { 1 };
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -30,13 +31,23 @@ A metaclass that pretends that all instances consume every role.
 
 This metaclass is internal and not meant for use outside Magpie
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Oliver Charles
+=over 4
+
+=item *
+
+Oliver Charles <oliver.g.charles@googlemail.com>
+
+=item *
+
+Steven Lee <stevenwh.lee@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Oliver Charles <oliver.g.charles@googlemail.com>.
+This software is copyright (c) 2013 by Oliver Charles.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
