@@ -1,6 +1,6 @@
 package Test::Magpie::Role::HasMock;
 {
-  $Test::Magpie::Role::HasMock::VERSION = '0.06';
+  $Test::Magpie::Role::HasMock::VERSION = '0.07';
 }
 # ABSTRACT: A role for objects that wrap around a mock
 use Moose::Role;
@@ -33,13 +33,23 @@ The mock object itself. No accessor is generated. Required.
 
 This class is internal, and not meant for use outside Magpie.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Oliver Charles
+=over 4
+
+=item *
+
+Oliver Charles <oliver.g.charles@googlemail.com>
+
+=item *
+
+Steven Lee <stevenwh.lee@gmail.com>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Oliver Charles <oliver.g.charles@googlemail.com>.
+This software is copyright (c) 2013 by Oliver Charles.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
